#!/bin/bash
#Copyright 2020 - Atomicorp, Inc.
export VERSION="Atomicorp Enterprise Remote Support system 1.3"
export ATOMICORP_TMP="/root/atomicorp-tmp"
export SUPPORT_IP="10.8.0.1"
export SUPPORT_SERVER="173.203.184.213"
export INTERNAL_IP="10.8.0.1"

echo $VERSION

#TODO: 
#Add option to use UDP or TCP
#backup contents of openvpn dir
# Remove SSH keys
# make separate instance of openvpn for just support

#options
#	enable - starts session
#	disable - turns off session and
#	anything else, show usage

usage () {
        echo "Usage : to enable remote support access run:"
	echo " $0 enable"
	echo
	echo "To disable remote support access run:"
	echo " $0 disable"
        exit
}

#enable function
enable () {
	echo "Please send the full output of this process to support@atomicorp.com"
	echo

	#install our keys
	echo "Installing PKI keys"
	wget -q -O - https://updates.atomicorp.com/installers/enterprise-key |bash

	echo "Checking to see if remote support is installed"
	#install EPEL and openvpn
	yum install epel-release -y
	yum -y install openvpn

	#grab reverse tunnel config file
	echo "Grabbing configuration"
	rm -rf $ATOMICORP_TMP
	mkdir $ATOMICORP_TMP
	wget -q -O - https://www.atomicorp.com/enterprise/remote-support.tar.gz > $ATOMICORP_TMP/remote-support.tar.gz
	tar zxvf $ATOMICORP_TMP/remote-support.tar.gz -C /etc/openvpn

	echo
	read -r -p "Does this network require you to connect thru an HTTP proxy? (y/n) " response
	if [[ "$response" =~ ^([yY][eE][sS]|[yY])$ ]]
	then
    		read -p  "Please enter the proxies IP address or full hostname: " PROXY_IP

    		read -p "Please enter the proxies TCP port number: " PROXY_PORT

		read -r -p "Does this proxy require a username and password? " response
		if [[ "$response" =~ ^([yY][eE][sS]|[yY])$ ]]
		then

		read -r -p "Does the proxy user BASIC or NTLM authentication (basic/ntlm): " AUTH_TYPE

			#add this to the config file
			# http-proxy	$PROXY_IP $PROXY_PORT stdin basic
			echo "http-proxy    $PROXY_IP $PROXY_PORT stdin $AUTH_TYPE" >> /etc/openvpn/openvpn.conf
			echo "You will be prompted to enter the proxy username and password when remote support is started in a moment"

		else
			echo "No username and password required for this proxy"
			echo "http-proxy    $PROXY_IP $PROXY_PORT" >> /etc/openvpn/client.conf
	fi
	else
    		echo "HTTP proxy not required"
	fi

	echo "Enabling remote support"
	systemctl enable openvpn@client
	echo "Starting remote support"
	systemctl start openvpn@client
	if [ $? -eq 0 ]; then
		echo "Remote support started"

		#test connectivity of tunnel
		echo "Testing if support can access hub"
		ping -c 10  $INTERNAL_IP
		if [ $? -eq 0 ]; then

                	echo "Remote support can connect"
			echo -n "Hub IP is: "  
			ifconfig -a | grep -A 2 tun

		else
			echo "remote support can not connect"
			echo "Send the /var/log/messages file to support@atomicorp.com" 
		exit 1

		fi

		
	else
    		echo "The remote support service was not able to start"
		echo "Send the /var/log/messages file to support@atomicorp.com" 
		exit 1
	fi


}

#disable function
disable () {

	#stop tunnel
	systemctl stop openvpn@client

	#disable tunnel
	systemctl disable openvpn@client

	#remove keys
}

if [ $# -lt 1 ]
then
	usage
fi


case "$1" in
	enable) enable
	;;
	disable) disable
	;;

	*) usage
	exit 1
   ;;

esac

